function b=minfil(a,f);
% minfil performs a minimum filter over the columns of a. f is the size of
% the filter.
% b : minimum filtered image
% a : input image
% f : filter size
%
[r,c]= size(a);
b=a;
for i1=f+1:r-f
	b(i1,:)=min(a(i1-f:i1+f,:));
end
